@@ -24,8 +24,8 @@ from typing import (
 
 import libsbml
 import numpy as np
-import numpy.typing as npt
 
+from ..typing import Array
 from .basemodel import BaseModel
 from .compoundmixin import CompoundMixin
 from .parametermixin import ParameterMixin
@@ -471,9 +471,9 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
     def _get_fcd(
         self,
         *,
-        t: npt.NDArray[np.float64],
-        y: Dict[str, npt.NDArray[np.float64]],
-    ) -> Dict[str, npt.NDArray[np.float64]]:
+        t: Array,
+        y: Dict[str, Array],
+    ) -> Dict[str, Array]:
         """Calculate the derived variables of all algebraic modules.
 
         fdc = full_concentration_dict
@@ -483,7 +483,7 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         """
         y["time"] = t
         # args = self.parameters | y # that is python 3.9+ syntax, wait for a bit
-        args: Dict[str, Union[float, npt.NDArray[np.float64]]] = {**self.parameters, **y}
+        args: Dict[str, Union[float, Array]] = {**self.parameters, **y}
         for name, module in self.algebraic_modules.items():
             try:
                 derived_values = module.function(*(args[arg] for arg in module.args))
