@@ -14,8 +14,8 @@ from typing import Any, Callable, Dict, Generator, List, Optional, Tuple
 
 import libsbml
 import numpy as np
-import numpy.typing as npt
 
+from ..typing import Array
 from . import BaseModel, CompoundMixin, ParameterMixin
 from .utils import (
     check_function_arity,
@@ -514,7 +514,7 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
         self,
         *,
         fcd: Dict[str, float],
-    ) -> Dict[str, npt.NDArray[np.float64]]:
+    ) -> Dict[str, Array]:
         # args = self.parameters | fcd # python 3.9+ syntax
         args = {**self.parameters, **fcd}
         fluxes = {}
