@@ -9,18 +9,18 @@ from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union, cast
 
 import libsbml
 import numpy as np
-import numpy.typing as npt
 import pandas as pd
 
 from ...core.compoundmixin import Compound
 from ...core.ratemixin import RateMeta
 from ...core.utils import convert_id_to_sbml, warning_on_one_line
+from ...typing import Array, ArrayLike
 from .model import Model
 
 warnings.formatwarning = warning_on_one_line  # type: ignore
 
 
-def total_concentration(*args: float) -> List[npt.NDArray[np.float64]]:
+def total_concentration(*args: float) -> List[Array]:
     """Return concentration of all isotopomers.
 
     Algebraic module function to keep track of the total
@@ -757,7 +757,7 @@ class LabelModel(Model):
 
     def generate_y0(
         self,
-        base_y0: Union[List[float], Dict[str, float]],
+        base_y0: Union[ArrayLike, Dict[str, float]],
         label_positions: Dict[str, Union[int, List[int]]] = None,
     ) -> Dict[str, float]:
         """Generate y0 for all isotopomers given a base y0.
@@ -794,9 +794,9 @@ class LabelModel(Model):
     def get_total_fluxes(
         self,
         rate_base_name: str,
-        y: Union[Dict[str, float], Dict[str, List[float]]],
-        t: Union[float, List[float]] = 0,
-    ) -> npt.NDArray[np.float64]:
+        y: Union[Dict[str, float], Dict[str, ArrayLike]],
+        t: Union[float, ArrayLike] = 0,
+    ) -> Array:
         """Get total fluxes of a base rate.
 
         Parameters
@@ -811,7 +811,7 @@ class LabelModel(Model):
         """
         rates = [i for i in self.rates if i.startswith(rate_base_name + "__")]
         return cast(
-            npt.NDArray[np.float64],
+            Array,
             self.get_fluxes_df(y=y, t=t)[rates].sum(axis=1).values,  # type: ignore
         )
 
