@@ -13,7 +13,6 @@ from typing import Any, Callable, Dict, List, Optional, Union, cast
 
 import libsbml
 import numpy as np
-import numpy.typing as npt
 import pandas as pd
 
 from ...core import (
@@ -25,6 +24,7 @@ from ...core import (
     StoichiometricMixin,
 )
 from ...core.utils import convert_id_to_sbml
+from ...typing import Array, ArrayLike
 from . import _AbstractRateModel
 
 
@@ -424,9 +424,9 @@ class Model(_AbstractRateModel):
 
     def get_full_concentration_dict(
         self,
-        y: Union[Dict[str, float], Dict[str, npt.NDArray[np.float64]], List[float], npt.NDArray[np.float64]],
-        t: Union[float, List[float], npt.NDArray[np.float64]] = 0.0,
-    ) -> Dict[str, npt.NDArray[np.float64]]:
+        y: Union[Dict[str, float], Dict[str, Array], ArrayLike, Array],
+        t: Union[float, ArrayLike, Array] = 0.0,
+    ) -> Dict[str, Array]:
         """Calculate the derived variables (at time(s) t).
 
         Examples
@@ -448,13 +448,13 @@ class Model(_AbstractRateModel):
         self,
         y: Union[
             Dict[str, float],
-            Dict[str, List[float]],
-            Dict[str, npt.NDArray[np.float64]],
-            npt.NDArray[np.float64],
-            List[float],
+            Dict[str, ArrayLike],
+            Dict[str, Array],
+            Array,
+            ArrayLike,
         ],
-        t: Union[float, List[float], npt.NDArray[np.float64]] = 0.0,
-    ) -> Dict[str, npt.NDArray[np.float64]]:
+        t: Union[float, ArrayLike, Array] = 0.0,
+    ) -> Dict[str, Array]:
         """Calculate the fluxes at time point(s) t."""
         self._update_derived_parameters()
         fcd = self.get_full_concentration_dict(y=y, t=t)  # type: ignore
@@ -467,13 +467,13 @@ class Model(_AbstractRateModel):
         self,
         y: Union[
             Dict[str, float],
-            Dict[str, List[float]],
-            Dict[str, npt.NDArray[np.float64]],
-            npt.NDArray[np.float64],
-            List[float],
+            Dict[str, ArrayLike],
+            Dict[str, Array],
+            Array,
+            ArrayLike,
         ],
-        t: Union[float, List[float], npt.NDArray[np.float64]] = 0.0,
-    ) -> npt.NDArray[np.float64]:
+        t: Union[float, ArrayLike, Array] = 0.0,
+    ) -> Array:
         """Calculate the fluxes at time point(s) t."""
         return np.array(list(self.get_fluxes_dict(y=y, t=t).values())).T
 
@@ -481,12 +481,12 @@ class Model(_AbstractRateModel):
         self,
         y: Union[
             Dict[str, float],
-            Dict[str, List[float]],
-            Dict[str, npt.NDArray[np.float64]],
-            npt.NDArray[np.float64],
-            List[float],
+            Dict[str, ArrayLike],
+            Dict[str, Array],
+            Array,
+            ArrayLike,
         ],
-        t: Union[float, List[float], npt.NDArray[np.float64]] = 0.0,
+        t: Union[float, ArrayLike, Array] = 0.0,
     ) -> pd.DataFrame:
         """Calculate the fluxes at time point(s) t."""
         if isinstance(t, (int, float)):
@@ -495,9 +495,7 @@ class Model(_AbstractRateModel):
 
     # This can't get keyword-only arguments, as the integrators are calling it with
     # positional arguments
-    def _get_rhs(
-        self, t: Union[float, List[float], npt.NDArray[np.float64]], y: List[npt.NDArray[np.float64]]
-    ) -> npt.NDArray[np.float64]:
+    def _get_rhs(self, t: Union[float, ArrayLike, Array], y: List[Array]) -> Array:
         """Calculate the right hand side of the ODE system.
 
         This is the more performant version of get_right_hand_side()
@@ -519,12 +517,12 @@ class Model(_AbstractRateModel):
         self,
         y: Union[
             Dict[str, float],
-            Dict[str, List[float]],
-            Dict[str, npt.NDArray[np.float64]],
-            npt.NDArray[np.float64],
-            List[float],
+            Dict[str, ArrayLike],
+            Dict[str, Array],
+            Array,
+            ArrayLike,
         ],
-        t: Union[float, List[float], npt.NDArray[np.float64]] = 0.0,
+        t: Union[float, ArrayLike, Array] = 0.0,
     ) -> Dict[str, float]:
         """Calculate the right hand side of the ODE system."""
         self._update_derived_parameters()
