@@ -29,12 +29,10 @@ from typing import (
 
 import matplotlib.pyplot as plt
 import numpy as np
-import numpy.typing as npt
 import pandas as pd
-from matplotlib.figure import Figure
 from tqdm.auto import tqdm
 
-from ...typing import Axes
+from ...typing import Array, ArrayLike, Axes, Axis, Figure
 from ...utils.plotting import _get_plot_kwargs, _style_subplot, plot, plot_grid
 from ..integrators import AbstractIntegrator
 from . import BASE_MODEL_TYPE, RATE_MODEL_TYPE
@@ -45,9 +43,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
         self,
         model: BASE_MODEL_TYPE,
         integrator: Type[AbstractIntegrator],
-        y0: Optional[List[float]] = None,
-        time: Optional[List[npt.NDArray[np.float64]]] = None,
-        results: Optional[List[npt.NDArray[np.float64]]] = None,
+        y0: Optional[ArrayLike] = None,
+        time: Optional[List[Array]] = None,
+        results: Optional[List[Array]] = None,
     ) -> None:
         self.model = model
         self._integrator = integrator
@@ -80,7 +78,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
         if self.integrator is not None:
             self.integrator.reset()
 
-    def _initialise_integrator(self, *, y0: Union[npt.NDArray[np.float64], List[float]]) -> None:
+    def _initialise_integrator(self, *, y0: ArrayLike) -> None:
         """Initialise the integrator.
 
         Required for assimulo, as it needs y0 to initialise
@@ -99,9 +97,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
     def _normalise_split_array(
         self,
         *,
-        split_array: List[npt.NDArray[np.float64]],
-        normalise: Union[float, List[float]],
-    ) -> List[npt.NDArray[np.float64]]:
+        split_array: List[Array],
+        normalise: Union[float, ArrayLike],
+    ) -> List[Array]:
         if isinstance(normalise, (int, float)):
             return [i / normalise for i in split_array]
         if len(normalise) == len(split_array):
@@ -120,9 +118,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
     def _test_run(self) -> None:
         """Perform a test step of the simulation in Python to get proper error handling."""
 
-    def _save_simulation_results(
-        self, *, time: npt.NDArray[np.float64], results: npt.NDArray[np.float64], skipfirst: bool
-    ) -> None:
+    def _save_simulation_results(self, *, time: Array, results: Array, skipfirst: bool) -> None:
         if self.time is None or self.results is None:
             self.time = [time]
             self.results = [results]
@@ -134,9 +130,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
                 self.time.append(time)
                 self.results.append(results)
 
-    def get_time(
-        self, concatenated: bool = True
-    ) -> Union[None, npt.NDArray[np.float64], List[npt.NDArray[np.float64]]]:
+    def get_time(self, concatenated: bool = True) -> Union[None, Array, List[Array]]:
         """Get simulation time.
 
         Returns
@@ -151,11 +145,11 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
 
     def simulate(
         self,
-        t_end: float = None,
-        steps: int = None,
-        time_points: List[float] = None,
+        t_end: Optional[float] = None,
+        steps: Optional[int] = None,
+        time_points: Optional[ArrayLike] = None,
         **integrator_kwargs: Dict[str, Any],
-    ) -> Tuple[Optional[npt.NDArray[np.float64]], Optional[npt.NDArray[np.float64]]]:
+    ) -> Tuple[Optional[Array], Optional[Array]]:
         """Simulate the model."""
         if self.integrator is None:
             raise AttributeError("Initialise the simulator first.")
@@ -205,7 +199,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
         tolerance: float = 1e-6,
         simulation_kwargs: Dict[str, Any] = None,
         **integrator_kwargs: Dict[str, Any],
-    ) -> Tuple[Optional[npt.NDArray[np.float64]], Optional[npt.NDArray[np.float64]]]:
+    ) -> Tuple[Optional[Array], Optional[Array]]:
         """Simulate the model."""
         if self.integrator is None:
             raise AttributeError("Initialise the simulator first.")
@@ -225,9 +219,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
 
     def get_results_array(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
-    ) -> Union[None, npt.NDArray[np.float64], List[npt.NDArray[np.float64]]]:
+    ) -> Union[None, Array, List[Array]]:
         """Get simulation results."""
         if self.results is None:
             return None
@@ -241,22 +235,22 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
 
     def get_results_dict(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
-    ) -> Union[None, Dict[str, npt.NDArray[np.float64]], List[Dict[str, npt.NDArray[np.float64]]]]:
+    ) -> Union[None, Dict[str, Array], List[Dict[str, Array]]]:
         """Get simulation results."""
         results = self.get_results_array(normalise=normalise, concatenated=concatenated)
         if results is None:
             return None
         if concatenated:
-            results = cast(npt.NDArray[np.float64], results)  # this is just a typing annotation
+            results = cast(Array, results)  # this is just a typing annotation
             return dict(zip(self.model.get_compounds(), results.T))
-        results = cast(List[npt.NDArray[np.float64]], results)  # this is just a typing annotation
+        results = cast(List[Array], results)  # this is just a typing annotation
         return [dict(zip(self.model.get_compounds(), i.T)) for i in results]
 
     def get_results_df(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
     ) -> Union[None, pd.DataFrame, List[pd.DataFrame]]:
         """Get simulation results."""
@@ -293,11 +287,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
             raise ValueError("Cannot save results, since none are stored in the simulator")
 
         res = cast(
-            Dict[str, npt.NDArray[np.float64]], self.get_results_dict(concatenated=True)
-        )  # cast is just typing annotation
-        time = cast(
-            npt.NDArray[np.float64], self.get_time(concatenated=True)
+            Dict[str, Array], self.get_results_dict(concatenated=True)
         )  # cast is just typing annotation
+        time = cast(Array, self.get_time(concatenated=True))  # cast is just typing annotation
         res["time"] = time
 
         res = {k: v.tolist() for k, v in res.items()}
@@ -326,7 +318,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
         """
         if filetype == "json":
             with open(filename, "r") as f:
-                res: Dict[str, npt.NDArray[np.float64]] = json.load(fp=f)
+                res: Dict[str, Array] = json.load(fp=f)
         elif filetype == "pickle":
             with open(filename, "rb") as f:  # type: ignore
                 res = pickle.load(file=f)  # type: ignore
@@ -345,14 +337,14 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         self,
         model: RATE_MODEL_TYPE,
         integrator: Type[AbstractIntegrator],
-        y0: Optional[List[float]] = None,
-        time: Optional[List[npt.NDArray[np.float64]]] = None,
-        results: Optional[List[npt.NDArray[np.float64]]] = None,
+        y0: Optional[ArrayLike] = None,
+        time: Optional[List[Array]] = None,
+        results: Optional[List[Array]] = None,
         parameters: List[Dict[str, float]] = None,
     ) -> None:
         _BaseSimulator.__init__(self, model=model, integrator=integrator, y0=y0, time=time, results=results)
-        self.full_results: Optional[List[npt.NDArray[np.float64]]] = None
-        self.fluxes: Optional[List[npt.NDArray[np.float64]]] = None
+        self.full_results: Optional[List[Array]] = None
+        self.fluxes: Optional[List[Array]] = None
         self.simulation_parameters = parameters
 
     def __reduce__(self) -> Any:
@@ -401,7 +393,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def initialise(
         self,
-        y0: Union[List[float], npt.NDArray[np.float64], Dict[str, float]],
+        y0: Union[ArrayLike, Dict[str, float]],
         test_run: bool = True,
     ) -> None:
         """Initialise the integrator."""
@@ -424,9 +416,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         """Update model parameters."""
         self.model.update_parameters(parameters=parameters)
 
-    def _save_simulation_results(
-        self, *, time: npt.NDArray[np.float64], results: npt.NDArray[np.float64], skipfirst: bool
-    ) -> None:
+    def _save_simulation_results(self, *, time: Array, results: Array, skipfirst: bool) -> None:
         super()._save_simulation_results(time=time, results=results, skipfirst=skipfirst)
         if self.simulation_parameters is None:
             self.simulation_parameters = []
@@ -436,9 +426,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         self,
         t_end: Optional[float] = None,
         steps: Optional[int] = None,
-        time_points: Optional[List[float]] = None,
+        time_points: Optional[ArrayLike] = None,
         **integrator_kwargs: Dict[str, Any],
-    ) -> Tuple[Optional[npt.NDArray[np.float64]], Optional[npt.NDArray[np.float64]]]:
+    ) -> Tuple[Optional[Array], Optional[Array]]:
         """Simulate the model.
 
         You can either supply only a terminal time point, or additionally also the
@@ -471,7 +461,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tolerance: float = 1e-8,
         simulation_kwargs: Dict[str, Any] = None,
         **integrator_kwargs: Dict[str, Any],
-    ) -> Tuple[Optional[npt.NDArray[np.float64]], Optional[npt.NDArray[np.float64]]]:
+    ) -> Tuple[Optional[Array], Optional[Array]]:
         """Simulate the model to steady state."""
         self.model._update_derived_parameters()
         time, results = super().simulate_to_steady_state(
@@ -489,8 +479,8 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         else:
             fluxes = []
             for t, y, pars in zip(
-                cast(List[npt.NDArray[np.float64]], self.time),
-                cast(List[npt.NDArray[np.float64]], self.results),
+                cast(List[Array], self.time),
+                cast(List[Array], self.results),
                 cast(List[Dict[str, float]], self.simulation_parameters),
             ):
                 self.update_parameters(parameters=pars)
@@ -500,15 +490,15 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_fluxes_array(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
-    ) -> Optional[Union[npt.NDArray[np.float64], List[npt.NDArray[np.float64]]]]:
+    ) -> Optional[Union[Array, List[Array]]]:
         """Get the model fluxes for the simulation."""
         if self.time is None or self.results is None:
             return None
         if self.fluxes is None:
             self._calculate_fluxes()
-        fluxes = cast(List[npt.NDArray[np.float64]], self.fluxes)
+        fluxes = cast(List[Array], self.fluxes)
         if normalise is not None:
             fluxes = self._normalise_split_array(split_array=fluxes, normalise=normalise)
         if concatenated:
@@ -517,20 +507,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_fluxes_dict(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
-    ) -> Optional[Union[Dict[str, npt.NDArray[np.float64]], List[Dict[str, npt.NDArray[np.float64]]]]]:
+    ) -> Optional[Union[Dict[str, Array], List[Dict[str, Array]]]]:
         """Get the model fluxes for the simulation."""
         fluxes = self.get_fluxes_array(normalise=normalise, concatenated=concatenated)
         if fluxes is None:
             return None
         if concatenated:
-            return dict(zip(self.model.rates, cast(npt.NDArray[np.float64], fluxes).T))
+            return dict(zip(self.model.rates, cast(Array, fluxes).T))
         return [dict(zip(self.model.rates, i.T)) for i in fluxes]
 
     def get_fluxes_df(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
     ) -> Optional[Union[pd.DataFrame, List[pd.DataFrame]]]:
         """Get the model fluxes for the simulation."""
@@ -564,9 +554,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_full_results_array(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
-    ) -> Optional[Union[npt.NDArray[np.float64], List[npt.NDArray[np.float64]]]]:
+    ) -> Optional[Union[Array, List[Array]]]:
         """Get simulation results and derived compounds.
 
         Returns
@@ -577,7 +567,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
             return None
         if self.full_results is None:
             self._calculate_full_results()
-        full_results = cast(List[npt.NDArray[np.float64]], self.full_results).copy()
+        full_results = cast(List[Array], self.full_results).copy()
         if normalise is not None:
             full_results = self._normalise_split_array(
                 split_array=full_results,
@@ -589,21 +579,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_full_results_dict(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
-    ) -> Optional[Union[Dict[str, npt.NDArray[np.float64]], List[Dict[str, npt.NDArray[np.float64]]]]]:
+    ) -> Optional[Union[Dict[str, Array], List[Dict[str, Array]]]]:
         """Get simulation results and derived compounds."""
         full_results = self.get_full_results_array(normalise=normalise, concatenated=concatenated)
         if full_results is None:
             return None
         all_compounds = self.model.get_all_compounds()
         if concatenated:
-            return dict(zip(all_compounds, cast(npt.NDArray[np.float64], full_results).T))
+            return dict(zip(all_compounds, cast(Array, full_results).T))
         return [dict(zip(all_compounds, i.T)) for i in full_results]
 
     def get_full_results_df(
         self,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
     ) -> Optional[Union[pd.DataFrame, List[pd.DataFrame]]]:
         """Get simulation results and derived compounds."""
@@ -620,9 +610,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def get_variable(
         self,
         variable: str,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
-    ) -> Optional[Union[npt.NDArray[np.float64], List[npt.NDArray[np.float64]]]]:
+    ) -> Optional[Union[Array, List[Array]]]:
         """Get simulation results for a specific variable.
 
         Returns
@@ -633,15 +623,15 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         if full_results_dict is None:
             return None
         if concatenated:
-            return cast(Dict[str, npt.NDArray[np.float64]], full_results_dict)[variable]
-        return [i[variable] for i in cast(List[Dict[str, npt.NDArray[np.float64]]], full_results_dict)]
+            return cast(Dict[str, Array], full_results_dict)[variable]
+        return [i[variable] for i in cast(List[Dict[str, Array]], full_results_dict)]
 
     def get_variables(
         self,
         variables: List[str],
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         concatenated: bool = True,
-    ) -> Union[npt.NDArray[np.float64], List[npt.NDArray[np.float64]]]:
+    ) -> Union[Array, List[Array]]:
         """Get simulation results for a specific variable."""
         full_results_df = self.get_full_results_df(normalise=normalise, concatenated=concatenated)
         if concatenated:
@@ -679,7 +669,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         concentrations = dict(s.get_full_results_df(concatenated=True).iloc[-1])  # type: ignore
         return parameter_value, concentrations, fluxes  # type: ignore
 
-    def _scan_threading(self, parameter_name: str, parameter_values: list[float], worker: Callable) -> list:
+    def _scan_threading(self, parameter_name: str, parameter_values: ArrayLike, worker: Callable) -> list:
         with tqdm(total=len(parameter_values), desc=parameter_name) as pbar:
             results = []
             for value in parameter_values:
@@ -688,7 +678,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         return results
 
     def _scan_multiprocessing(
-        self, parameter_name: str, parameter_values: list[float], worker: Callable
+        self, parameter_name: str, parameter_values: ArrayLike, worker: Callable
     ) -> list:
         with tqdm(total=len(parameter_values), desc=parameter_name) as pbar:
             with futures.ProcessPoolExecutor() as executor:
@@ -701,7 +691,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def parameter_scan(
         self,
         parameter_name: str,
-        parameter_values: List[float],
+        parameter_values: ArrayLike,
         tolerance: float = 1e-8,
         multiprocessing: bool = True,
         **integrator_kwargs: Dict[str, Any],
@@ -738,7 +728,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def parameter_scan_with_fluxes(
         self,
         parameter_name: str,
-        parameter_values: List[float],
+        parameter_values: ArrayLike,
         tolerance: float = 1e-8,
         multiprocessing: bool = True,
         **integrator_kwargs: Dict[str, Any],
@@ -776,8 +766,8 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def parameter_scan_2d(
         self,
-        p1: Tuple[str, List[float]],
-        p2: Tuple[str, List[float]],
+        p1: Tuple[str, ArrayLike],
+        p2: Tuple[str, ArrayLike],
         tolerance: float = 1e-8,
         multiprocessing: bool = True,
         **integrator_kwargs: Dict[str, Any],
@@ -800,8 +790,8 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def parameter_scan_2d_with_fluxes(
         self,
-        p1: Tuple[str, List[float]],
-        p2: Tuple[str, List[float]],
+        p1: Tuple[str, ArrayLike],
+        p2: Tuple[str, ArrayLike],
         tolerance: float = 1e-8,
         multiprocessing: bool = True,
         **integrator_kwargs: Dict[str, Any],
@@ -830,10 +820,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         xlabel: str = None,
         ylabel: str = None,
         title: str = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -842,7 +832,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_compounds()
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
         if y is None:
@@ -875,10 +865,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         xlabel: str = None,
         ylabel: str = None,
         title: str = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -887,7 +877,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_compounds()
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
         if y is None:
@@ -923,10 +913,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         xlabel: str = None,
         ylabel: str = None,
         title: str = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -935,7 +925,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_derived_compounds()
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
         if y is None:
@@ -964,10 +954,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         xlabel: str = None,
         ylabel: str = None,
         title: str = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -976,7 +966,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_all_compounds()
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
         if y is None:
@@ -1006,10 +996,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         xlabel: str = None,
         ylabel: str = None,
         title: str = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1018,7 +1008,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
         if y is None:
             return None, None
@@ -1049,7 +1039,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         sharey: bool = True,
         xlabels: List[str] = None,
         ylabels: List[str] = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         plot_titles: Optional[Iterable[str]] = None,
         figure_title: str = None,
         grid: bool = True,
@@ -1103,7 +1093,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1112,7 +1102,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
         results = cast(pd.DataFrame, self.get_full_results_df(concatenated=True))
@@ -1148,7 +1138,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1157,7 +1147,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
         results = cast(pd.DataFrame, self.get_full_results_df(concatenated=True))
@@ -1193,7 +1183,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1202,7 +1192,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
         results = cast(pd.DataFrame, self.get_full_results_df(concatenated=True))
@@ -1239,7 +1229,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1248,7 +1238,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
         results = cast(pd.DataFrame, self.get_full_results_df(concatenated=True))
@@ -1280,10 +1270,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         xlabel: str = None,
         ylabel: str = None,
         title: str = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1292,7 +1282,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         rate_names = cast(List[str], self.model.get_rate_names())
         y = self.get_fluxes_df(normalise=normalise, concatenated=True)
         if y is None:
@@ -1323,10 +1313,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         xlabel: str = None,
         ylabel: str = None,
         title: str = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1335,7 +1325,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         y = self.get_fluxes_df(normalise=normalise, concatenated=True)
         if y is None:
             return None, None
@@ -1367,7 +1357,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         sharey: bool = True,
         xlabels: List[str] = None,
         ylabels: List[str] = None,
-        normalise: Union[float, List[float]] = None,
+        normalise: Union[float, ArrayLike] = None,
         plot_titles: Optional[Iterable[str]] = None,
         figure_title: str = None,
         grid: bool = True,
@@ -1380,7 +1370,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[npt.NDArray[np.float64]]]:
+    ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot simulation results of the compound groups as a grid.
 
         Examples
@@ -1391,7 +1381,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         if fluxes is None:
             return None, None
         fluxes = cast(pd.DataFrame, fluxes)
-        plot_groups = [(cast(npt.NDArray[np.float64], fluxes.loc[:, group].values),) for group in rate_groups]
+        plot_groups = [(cast(Array, fluxes.loc[:, group].values),) for group in rate_groups]
         return plot_grid(
             plot_groups=plot_groups,  # type: ignore
             legend_groups=rate_groups,
@@ -1422,7 +1412,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1431,7 +1421,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
         rate_names = cast(List[str], self.model.get_rate_names())
@@ -1468,7 +1458,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1477,7 +1467,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
         x = self.get_variable(variable=variable)
@@ -1513,7 +1503,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1522,7 +1512,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = cpd1
         if ylabel is None:
@@ -1561,7 +1551,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1570,7 +1560,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         kwargs = _get_plot_kwargs(
             figure_kwargs=figure_kwargs,
             subplot_kwargs=subplot_kwargs,
@@ -1627,7 +1617,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1636,7 +1626,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         xlabel = cpd1 if xlabel is None else xlabel
         ylabel = cpd2 if ylabel is None else ylabel
 
@@ -1699,7 +1689,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title: str = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: plt.Axes = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Dict[str, Any] = None,
         subplot_kwargs: Dict[str, Any] = None,
         plot_kwargs: Dict[str, Any] = None,
@@ -1708,7 +1698,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         tick_kwargs: Dict[str, Any] = None,
         label_kwargs: Dict[str, Any] = None,
         title_kwargs: Dict[str, Any] = None,
-    ) -> Tuple[Optional[Figure], Optional[plt.Axes]]:
+    ) -> Tuple[Optional[Figure], Optional[Axis]]:
         kwargs = _get_plot_kwargs(
             figure_kwargs=figure_kwargs,
             subplot_kwargs=subplot_kwargs,
