@@ -7,12 +7,10 @@ __all__ = [
 import copy
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, Union, cast
 
-import matplotlib.pyplot as plt
-import numpy as np
-import numpy.typing as npt
 import pandas as pd
 from matplotlib.figure import Figure
 
+from ...typing import Array, ArrayLike, Axis
 from ...utils.plotting import plot, plot_grid
 from ..integrators import AbstractIntegrator as _AbstractIntegrator
 from ..models import LinearLabelModel as _LinearLabelModel
@@ -26,11 +24,11 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         self,
         model: _LinearLabelModel,
         integrator: Type[_AbstractIntegrator],
-        y0: Optional[List[float]] = None,
-        time: Optional[List[npt.NDArray[np.float64]]] = None,
-        results: Optional[List[npt.NDArray[np.float64]]] = None,
+        y0: Optional[ArrayLike] = None,
+        time: Optional[List[Array]] = None,
+        results: Optional[List[Array]] = None,
     ) -> None:
-        self.y0: Optional[List[float]]  # For some reasons mypy has problems finding this
+        self.y0: Optional[ArrayLike]  # For some reasons mypy has problems finding this
         super().__init__(
             model=model,
             integrator=integrator,
@@ -72,7 +70,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
 
     def initialise(
         self,
-        label_y0: Union[List[float], Dict[str, float]],
+        label_y0: Union[ArrayLike, Dict[str, float]],
         y_ss: Dict[str, float],
         v_ss: Dict[str, float],
         external_label: float = 1.0,
@@ -92,7 +90,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         if test_run:
             self._test_run()
 
-    def get_label_position(self, compound: str, position: int) -> Optional[npt.NDArray[np.float64]]:
+    def get_label_position(self, compound: str, position: int) -> Optional[Array]:
         """Get relative concentration of a single isotopomer.
 
         Examples
@@ -102,9 +100,9 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         res = self.get_results_dict(concatenated=True)
         if res is None:
             return None
-        return cast(Dict[str, npt.NDArray[np.float64]], res)[self.model.isotopomers[compound][position]]
+        return cast(Dict[str, Array], res)[self.model.isotopomers[compound][position]]
 
-    def get_label_distribution(self, compound: str) -> Optional[npt.NDArray[np.float64]]:
+    def get_label_distribution(self, compound: str) -> Optional[Array]:
         """Get relative concentrations of all compound isotopomers.
 
         Examples
@@ -116,7 +114,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         if res is None:
             return None
         res = cast(pd.DataFrame, res)
-        return cast(npt.NDArray[np.float64], res.loc[:, compounds].values)
+        return cast(Array, res.loc[:, compounds].values)
 
     def plot_label_distribution(
         self,
@@ -127,7 +125,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         title: Optional[str] = None,
         grid: bool = True,
         tight_layout: bool = True,
-        ax: Optional[plt.Axes] = None,
+        ax: Optional[Axis] = None,
         figure_kwargs: Optional[Dict[str, Any]] = None,
         subplot_kwargs: Optional[Dict[str, Any]] = None,
         plot_kwargs: Optional[Dict[str, Any]] = None,
@@ -136,7 +134,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
-    ) -> Tuple[Figure, plt.Axes]:
+    ) -> Tuple[Figure, Axis]:
         """Plot label distribution of a compound."""
         if ylabel is None and relative:
             ylabel = "Relative concentration"
@@ -185,7 +183,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
-    ) -> Tuple[Optional[Figure], Optional[npt.NDArray[np.float64]]]:
+    ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot label distributions of multiple compounds on a grid."""
         time = self.get_time()
         plot_groups = [(time, self.get_label_distribution(compound=compound)) for compound in compounds]
@@ -238,7 +236,7 @@ class _LinearLabelSimulate(_BaseSimulator[_LinearLabelModel]):
         tick_kwargs: Optional[Dict[str, Any]] = None,
         label_kwargs: Optional[Dict[str, Any]] = None,
         title_kwargs: Optional[Dict[str, Any]] = None,
-    ) -> Tuple[Optional[Figure], Optional[npt.NDArray[np.float64]]]:
+    ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot label distributions of all compounds on a grid."""
         time = self.get_time()
         compounds = self.model.isotopomers
