@@ -26,14 +26,13 @@ from typing import Dict, List, Optional, Tuple, Union, cast
 
 import matplotlib.pyplot as plt
 import numpy as np
-import numpy.typing as npt
 import pandas as pd
 from matplotlib import cm
 from matplotlib.collections import QuadMesh
 from matplotlib.figure import Figure
 from tqdm.auto import tqdm
 
-from ...typing import Axes
+from ...typing import Array, ArrayLike, Axes, Axis
 from ...utils.plotting import get_norm as _get_norm
 from ...utils.plotting import heatmap_from_dataframe as _heatmap_from_dataframe
 from ..models import Model
@@ -45,8 +44,8 @@ _DISPLACEMENT = 1e-4
 def _find_steady_state(
     *,
     model: Model,
-    y0: Union[List[float], npt.NDArray[np.float64], Dict[str, float]],
-) -> Tuple[Optional[npt.NDArray[np.float64]], Optional[npt.NDArray[np.float64]]]:
+    y0: Union[ArrayLike, Dict[str, float]],
+) -> Tuple[Optional[Array], Optional[Array]]:
     """Simulate the system to steadt state."""
     s = Simulator(model=model)
     s.initialise(y0=y0, test_run=False)
@@ -61,7 +60,7 @@ def get_compound_elasticity(
     t: float = 0,
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> npt.NDArray[np.float64]:
+) -> Array:
     """Get sensitivity of all rates to a change of the concentration of a compound.
 
     Also called epsilon-elasticities. Not in steady state!
@@ -80,7 +79,7 @@ def get_compound_elasticity(
         fcd[compound] = old_concentration
         flux_array = model.get_fluxes_array(y=fcd, t=t)
         elasticity_coef *= old_concentration / flux_array
-    return cast(npt.NDArray[np.float64], np.atleast_1d(np.squeeze(elasticity_coef)))
+    return cast(Array, np.atleast_1d(np.squeeze(elasticity_coef)))
 
 
 def get_compound_elasticities_array(
@@ -90,7 +89,7 @@ def get_compound_elasticities_array(
     t: float = 0,
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> npt.NDArray[np.float64]:
+) -> Array:
     """Get sensitivity of all rates to a change of the concentration of multiple compounds.
 
     Also called epsilon-elasticities. Not in steady state!
@@ -138,7 +137,7 @@ def get_parameter_elasticity(
     t: float = 0,
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> npt.NDArray[np.float64]:
+) -> Array:
     """Get sensitivity of all rates to a change of a parameter value.
 
     Also called pi-elasticities. Not in steady state!
@@ -154,7 +153,7 @@ def get_parameter_elasticity(
         model.update_parameter(parameter_name=parameter, parameter_value=old_value)
         fluxes_array = model.get_fluxes_array(y=y, t=t)
         elasticity_coef *= old_value / fluxes_array
-    return cast(npt.NDArray[np.float64], np.atleast_1d(np.squeeze(elasticity_coef)))
+    return cast(Array, np.atleast_1d(np.squeeze(elasticity_coef)))
 
 
 def get_parameter_elasticities_array(
@@ -164,7 +163,7 @@ def get_parameter_elasticities_array(
     t: float = 0,
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> npt.NDArray[np.float64]:
+) -> Array:
     """Get sensitivity of all rates to a change of multiple parameter values.
 
     Also called pi-elasticities. Not in steady state!
@@ -207,10 +206,10 @@ def get_parameter_elasticities_df(
 def get_response_coefficients(
     model: Model,
     parameter: str,
-    y: Union[Dict[str, float], npt.NDArray[np.float64], List],
+    y: Union[Dict[str, float], Array, List],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> Tuple[Optional[npt.NDArray[np.float64]], Optional[npt.NDArray[np.float64]]]:
+) -> Tuple[Optional[Array], Optional[Array]]:
     """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
     model = model.copy()
     old_value = model.get_parameter(parameter_name=parameter)
@@ -224,8 +223,8 @@ def get_response_coefficients(
         y_ss_norm = old_value / np.fromiter(fcd.values(), dtype="float")
         fluxes_array_norm = old_value / fluxes_array_norm
 
-    ss: list[npt.NDArray[np.float64]] = []
-    fluxes: list[npt.NDArray[np.float64]] = []
+    ss: list[Array] = []
+    fluxes: list[Array] = []
     for new_value in [
         old_value * (1 + displacement),
         old_value * (1 - displacement),
@@ -239,8 +238,8 @@ def get_response_coefficients(
         ss.append(np.fromiter(fcd.values(), dtype="float"))
         fluxes.append(model.get_fluxes_array(y=y_ss, t=t_ss))
 
-    conc_resp_coef: npt.NDArray[np.float64] = (ss[0] - ss[1]) / (2 * displacement * old_value)
-    flux_resp_coef: npt.NDArray[np.float64] = (fluxes[0] - fluxes[1]) / (2 * displacement * old_value)
+    conc_resp_coef: Array = (ss[0] - ss[1]) / (2 * displacement * old_value)
+    flux_resp_coef: Array = (fluxes[0] - fluxes[1]) / (2 * displacement * old_value)
 
     if normalized:
         conc_resp_coef *= y_ss_norm  # type: ignore
@@ -254,7 +253,7 @@ def get_response_coefficients_array(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> Tuple[npt.NDArray[np.float64], npt.NDArray[np.float64]]:
+) -> Tuple[Array, Array]:
     """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
     crcs = np.full(shape=(len(parameters), len(model.get_all_compounds())), fill_value=np.nan)
     frcs = np.full(shape=(len(parameters), len(model.get_rate_names())), fill_value=np.nan)
@@ -307,7 +306,7 @@ def get_concentration_response_coefficient(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> Optional[npt.NDArray[np.float64]]:
+) -> Optional[Array]:
     """Get response of the steady state concentrations to a change of the given parameter."""
     return get_response_coefficients(
         model=model, parameter=parameter, y=y, normalized=normalized, displacement=displacement
@@ -320,7 +319,7 @@ def get_concentration_response_coefficients_array(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> npt.NDArray[np.float64]:
+) -> Array:
     """Get response of the steady state concentrations to a change of the given parameters."""
     return get_response_coefficients_array(
         model=model,
@@ -354,7 +353,7 @@ def get_flux_response_coefficient(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> Optional[npt.NDArray[np.float64]]:
+) -> Optional[Array]:
     """Get response of the steady state fluxes to a change of the given parameter."""
     return get_response_coefficients(
         model=model, parameter=parameter, y=y, normalized=normalized, displacement=displacement
@@ -367,7 +366,7 @@ def get_flux_response_coefficients_array(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
-) -> npt.NDArray[np.float64]:
+) -> Array:
     """Get response of the steady state fluxes to a change of the given parameters."""
     return get_response_coefficients_array(
         model=model,
@@ -408,9 +407,9 @@ def plot_coefficient_heatmap(
     colorbar: bool = True,
     xlabel: str = None,
     ylabel: str = None,
-    ax: plt.Axes = None,
-    cax: plt.Axes = None,
-) -> Tuple[Figure, plt.Axes, QuadMesh]:
+    ax: Optional[Axis] = None,
+    cax: Optional[Axis] = None,
+) -> Tuple[Figure, Axis, QuadMesh]:
     """Plot the DataFrame of a response coefficient as a heatmap.
 
     Use the rows and columns arguments to only plot a subset of the data.
@@ -502,9 +501,9 @@ def plot_concentration_response_coefficients(
     colorbar: bool = True,
     xlabel: str = None,
     ylabel: str = None,
-    ax: plt.Axes = None,
-    cax: plt.Axes = None,
-) -> Tuple[Figure, plt.Axes, QuadMesh]:
+    ax: Optional[Axis] = None,
+    cax: Optional[Axis] = None,
+) -> Tuple[Figure, Axis, QuadMesh]:
     """Calculate and plot response of the steady state concentration to a change of the given parameters.
 
     See also
@@ -551,9 +550,9 @@ def plot_flux_response_coefficients(
     colorbar: bool = True,
     xlabel: str = None,
     ylabel: str = None,
-    ax: plt.Axes = None,
-    cax: plt.Axes = None,
-) -> Tuple[Figure, plt.Axes, QuadMesh]:
+    ax: Optional[Axis] = None,
+    cax: Optional[Axis] = None,
+) -> Tuple[Figure, Axis, QuadMesh]:
     """Calculate and plot response of the steady state fluxes to a change of the given parameters.
 
     See also
