@@ -14,10 +14,10 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union, cast
 
 import libsbml
 import numpy as np
-import numpy.typing as npt
 import sympy
 
 from ..ode import Model
+from ..typing import Array
 from .data import (
     AlgebraicRule,
     AssignmentRule,
